@@ -3,7 +3,7 @@ all.Phess<-function(){
      note_for_Phe_input()
      cat("\n")
      note_for_close_window()
-     PheSSpar<-data.frame(parameter=c("bw (kg)","D (mg)","tau (hr)","c (mg/L)"),value=c(0))
+     PheSSpar<-data.frame(parameter=c("BW (kg)","Dose (mg)","tau (hr)","Conc. (mg/L)"),value=c(0))
      PheSSpar<-edit(PheSSpar)
 ##     PheSSpar<-zcheck(PheSSpar)
      cat("\n")
@@ -14,9 +14,9 @@ all.Phess<-function(){
      show(samplesStats("*"))
      cat("\n") 
      C<-Phecpr(PheSSpar[2,2],PheSSpar[3,2])
-     sim<-matrix(C[1 ,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Cmss_pr (mg/L)")
+     Final<-(c(matrix(C[1 ,1]), PheSSpar[4,2]))
+     coutput<-data.frame(Final)
+     row.names(coutput)<-list("C(ss_calc)","C(ss_obs)")
      show(coutput)
      cat("\n")   
      Phe.more()
